# -*- coding: utf-8 -*-
##########################################################################
# NSAp - Copyright (C) CEA, 2023
# Distributed under the terms of the CeCILL-B license, as published by
# the CEA-CNRS-INRIA. Refer to the LICENSE file or to
# http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
# for details.
##########################################################################

"""
Registration tools.
"""

# Imports
import os
import subprocess
import numpy as np
import nibabel
from limri.color_utils import print_subtitle, print_result


def flirt(in_file, ref_file, out, omat=None, init=None, cost="corratio",
          usesqform=False, displayinit=False, anglerep="euler", bins=256,
          interp="trilinear", dof=12, applyxfm=False, applyisoxfm=None,
          nosearch=False, wmseg=None, verbose=0):
    """ Affine registration with FSL flirt.

    Parameters
    ----------
    in_file: str
        input volume.
    ref_file: str
        reference volume.
    out: str
        output volume
    omat: str, default None
        matrix filename - output in 4x4 ascii format.
    init: str, default None
        input 4x4 affine matrix
    cost: str, default 'corratio'
        choose the most appropriate option: 'mutualinfo', 'corratio',
        'normcorr', 'normmi', 'leastsq', 'labeldiff', 'bbr'.
    usesqform: bool, default False
        initialise using appropriate sform or qform.
    displayinit: bool, default False
        display initial matrix.
    anglerep: str, default 'euler'
        choose the most appropriate option: 'quaternion', 'euler'.
    bins: int, default 256
        number of histogram bins
    interp: str, default 'trilinear'
        choose the most appropriate option: 'trilinear', 'nearestneighbour',
        'sinc', 'spline'.
    dof: int, default 12
        number of transform dofs.
    applyxfm: bool, default False
        ppplies transform (no optimisation) - requires -init.
    applyisoxfm: float, default None
        the integer defines the scale - as applyxfm but forces isotropic
        resampling.
    verbose: int, default 0
        0 is least and default.
    nosearch: bool, default False
        if set perform no search to initialize the optimization.
    wmseg: str, default None
        white matter segmentation volume needed by BBR cost function.

    Returns
    -------
    out: str
        output volume.
    omat: str
        output matrix filename - output in 4x4 ascii format.
    """
    cmd = ["flirt",
           "-in", in_file,
           "-ref", ref_file,
           "-cost", cost,
           "-searchcost", cost,
           "-anglerep", anglerep,
           "-bins", str(bins),
           "-interp", interp,
           "-dof", str(dof),
           "-out", out,
           "-verbose", str(verbose)]
    if usesqform:
        cmd += ["-usesqform"]
    if displayinit:
        cmd += ["-displayinit"]
    if applyxfm:
        cmd += ["-applyxfm"]
    if nosearch:
        cmd += ["-nosearch"]
    if init is not None:
        cmd += ["-init", init]
    if applyisoxfm is not None:
        cmd += ["-applyisoxfm", str(applyisoxfm)]
    if cost == "bbr":
        cmd += ["-wmseg", wmseg]
    if not applyxfm:
        cmd += ["-omat", omat]
    subprocess.check_call(cmd)
    return out, omat


def applywarp(in_file, ref_file, out_file, warp_file, pre_affine_file=None,
              post_affine_file=None, interp="trilinear", verbose=0):
    """ Apply SPM deformation field.

    Parameters
    ----------
    in_file: str
        filename of input image (to be warped).
    ref_file: str
        filename for reference image.
    out_file: str
        filename for output (warped) image.
    warp_file: str
        filename for warp/coefficient (volume).
    pre_affine_file: str, default None
        filename for pre-transform (affine matrix).
    post_affine_file: str, default None
        filename for post-transform (affine matrix).
    interp: str, default 'trilinear'
        interpolation method {nn,trilinear,sinc,spline}
    verbose: int, default 0
        the verbosity level.
    """
    cmd = ["applywarp",
           "-i", in_file,
           "-r", ref_file,
           "-o", out_file,
           "-w", warp_file,
           "--abs",
           "--interp={0}".format(interp),
           "--verbose={0}".format(verbose)]
    if pre_affine_file is not None:
        cmd.append("--premat={0}".format(pre_affine_file))
    if post_affine_file is not None:
        cmd.append("--postmat={0}".format(post_affine_file))
    subprocess.check_call(cmd)


def flirt2aff(mat_file, in_file, ref_file):
    """ Map from 'in_file' image voxels to 'ref_file' voxels given `mat_file`
    omat FSL affine transformation.

    Parameters
    ------------
    mat_file: str
        filename of output '-omat' transformation file from FSL flirt.
    in_file: str
        filename of the image passed to flirt as the '-in' image.
    ref_file: str
        filename of the image passed to flirt as the '-ref' image.

    Returns
    -------
    omat: array (4, 4)
        array containing the transform from voxel coordinates in image
        for 'in_file' to voxel coordinates in image for 'ref_file'.
    """
    flirt_affine = np.loadtxt(mat_file)
    in_img = nibabel.load(in_file)
    ref_img = nibabel.load(ref_file)
    in_hdr = in_img.get_header()
    ref_hdr = ref_img.get_header()

    def _x_flipper(n):
        flipr = np.diag([-1, 1, 1, 1])
        flipr[0, 3] = n - 1
        return flipr

    inspace = np.diag(in_hdr.get_zooms()[:3] + (1, ))
    refspace = np.diag(ref_hdr.get_zooms()[:3] + (1, ))
    if np.linalg.det(in_img.get_affine()) >= 0:
        inspace = np.dot(inspace, _x_flipper(in_hdr.get_data_shape()[0]))
    if np.linalg.det(ref_img.get_affine()) >= 0:
        refspace = np.dot(refspace, _x_flipper(ref_hdr.get_data_shape()[0]))

    omat = np.dot(np.linalg.inv(refspace), np.dot(flirt_affine, inspace))

    return omat


def normalize2field():
    """ Transform a SPM normalization field to a FSL field.

    For the deformation fields generated in SPM, the values in each of the
    three components (ie (:,:,:,1,1), (:,:,:,1,2) and (:,:,:,1,3) ) encode
    the x,y,z coordinates of the corresponding location (in units of mm).

    SPM conventions:
    1) The file encodes the mapping rather than displacement fields for a
    couple of reasons:
    a) Even in 2012, many people still seem to think that displacements
    can be combined by addition or subtraction, rather than by composing
    or inverting the mappings.  (Attempting to compose deformations by
    adding the displacement fields would be analogous to saying 2*2=3 or
    3*3=5). Using the mapping instead of the displacements would (I hope)
    make this abuse a bit less likely.
    b) It saves needing to encode an additional affine transform matrix
    for dealing with the identity transform to which the displacements are
    added. This makes life simpler.
    2) It encodes coordinates in mm, rather than voxels. If the mapping
    was to voxels, it would not work so well for images that are in
    alignment via the matrices encoded by the sform or qform fields.
    Also, if the mapping is to voxels, the values would depend on whether
    the first voxel in the file is denoted as 1,1,1 (as in MATLAB, Fortran
    or SPM) or as 0,0,0 (as in C or FSL). The mm coordinates are
    unambiguous - providing the sform (or sform) fields of the image that
    the deformation points to is filled in.

    The bad news here is that you do need to use the sform (qform)
    information to convert from SPM to FSL conventions. In FSL we can use
    either absolute coordinates (as is used in SPM) or relative ones.
    However, our mm coordinate system is not the same, so you'll need to map
    between FSL's and SPM's if you want to get the warp correct.

    The problem you are experiencing will be about coordinate system
    conventions. Our mm coordinate system is just a scalar multiple of the
    voxel coordinates if the image has a negative sform (or qform)
    determinant. If the determinant of the sform (or qform) matrix is
    positive then is it the same except that the x-voxel-coordinate is
    flipped first (0 to N-1 becomes N-1 to 0). Note that this means that
    our origin is in the 0,0,0 voxel (the centre of the voxel) and that we
    do not use the qform or sform information (except for the sign of the
    determinant). If you can figure out what the SPM conventions are then you
    should be able to adjust for this, although it may not be easy.

    References
    ----------
    https://github.com/nipy/nitransforms
    https://www.jiscmail.ac.uk/cgi-bin/webadmin?A2=fsl;ed6a4473.1208
    """
    raise NotImplementedError


def antsregister(template_file, lianat_file, hanat_file, outdir):
    """ Compute the deformation field with Ants from a T1w image to a template.
    """
    try:
        import ants
    except:
        raise ImportError("You will need to install AntsPy to execute this "
                          "function.")

    print_subtitle("Load data...")
    lianat = ants.image_read(lianat_file)
    print_result(f"lianat spacing: {lianat.spacing}")
    print_result(f"lianat origin: {lianat.origin}")
    print_result(f"lianat direction: {lianat.direction}")
    filename = os.path.join(outdir, "lianat.png")
    lianat.plot_ortho(
        flat=True, xyz_lines=False, orient_labels=False,
        title="lianat", filename=filename)
    hanat = ants.image_read(hanat_file)
    print_result(f"hanat spacing: {hanat.spacing}")
    print_result(f"hanat origin: {hanat.origin}")
    print_result(f"hanat direction: {hanat.direction}")
    filename = os.path.join(outdir, "hanat.png")
    hanat.plot_ortho(
        flat=True, xyz_lines=False, orient_labels=False,
        title="hanat", filename=filename)
    template = ants.image_read(template_file)
    print_result(f"template spacing: {template.spacing}")
    print_result(f"template origin: {template.origin}")
    print_result(f"template direction: {template.direction}")
    filename = os.path.join(outdir, "template.png")
    template.plot_ortho(
        flat=True, xyz_lines=False, orient_labels=False,
        title="template", filename=filename)

    print_subtitle("Normalize...")
    lianat = ants.iMath_normalize(lianat)
    hanat = ants.iMath_normalize(hanat)
    template = ants.iMath_normalize(template)

    print_subtitle("Rigid: lianat -> hanat...")
    li2h = ants.registration(
        fixed=hanat, moving=lianat, type_of_transform="Rigid",
        outprefix=os.path.join(outdir, "li2h"))
    print_result(f"rigid transforms: {li2h['fwdtransforms']}")
    li2hanat = ants.apply_transforms(
        fixed=hanat, moving=lianat, transformlist=li2h["fwdtransforms"],
        interpolator="bSpline")
    filename = os.path.join(outdir, "li2hanat.nii.gz")
    li2hanat.to_filename(filename)
    print_result(f"li2h T1: {filename}")
    filename = os.path.join(outdir, "li2hanat.png")
    li2hanat.plot_ortho(
        hanat, flat=True, xyz_lines=False, orient_labels=False,
        title="li2hanat", filename=filename, overlay_alpha=0.5)

    print_subtitle("Rigid + Affine + deformation field: hanat -> template...")
    h2mni = ants.registration(
        fixed=template, moving=hanat, type_of_transform="SyNRA",
        outprefix=os.path.join(outdir, "h2mni"))
    print_result(f"deform transforms: {h2mni['fwdtransforms']}")
    jac = ants.create_jacobian_determinant_image(
        domain_image=hanat, tx=h2mni["fwdtransforms"][0])
    jac -= 1
    h2mnianat = ants.apply_transforms(
        fixed=template, moving=hanat, transformlist=h2mni["fwdtransforms"],
        interpolator="bSpline")
    h2mnijac = ants.apply_transforms(
        fixed=template, moving=jac, transformlist=h2mni["fwdtransforms"],
        interpolator="bSpline")
    li2mnianat = ants.apply_transforms(
        fixed=template, moving=lianat, interpolator="bSpline",
        transformlist=h2mni["fwdtransforms"] + li2h["fwdtransforms"])
    filename = os.path.join(outdir, "hjac.nii.gz")
    jac.to_filename(filename)
    print_result(f"h jacobian: {filename}")
    filename = os.path.join(outdir, "h2mnijac.nii.gz")
    h2mnijac.to_filename(filename)
    print_result(f"h2mni jacobian: {filename}")
    filename = os.path.join(outdir, "li2mnianat.nii.gz")
    li2mnianat.to_filename(filename)
    print_result(f"li2mni T1: {filename}")
    filename = os.path.join(outdir, "h2mnianat.nii.gz")
    h2mnianat.to_filename(filename)
    print_result(f"h2mni T1: {filename}")
    filename = os.path.join(outdir, "li2mnianat.png")
    li2mnianat.plot_ortho(
        template, flat=True, xyz_lines=False, orient_labels=False,
        title="li2mnianat", filename=filename, overlay_alpha=0.5)
    filename = os.path.join(outdir, "h2mnianat.png")
    h2mnianat.plot_ortho(
        template, flat=True, xyz_lines=False, orient_labels=False,
        title="h2mnianat", filename=filename, overlay_alpha=0.5)


def apply_transforms(fixed_file, moving_file, transformlist, filename):
    """ Apply a transform list to map an image from one domain to another.

    Parameters
    ----------
    fixed_file: str
        fixed image defining domain into which the moving image is transformed.
    moving_file: str
        moving image to be mapped to fixed space.
    transformlist: list of str
        list of transforms generated by ants.registration where each transform
        is a filename.
    filename: str
        the name of the transformed image.
    """
    try:
        import ants
    except:
        raise ImportError("You will need to install AntsPy to execute this "
                          "function.")

    fixed = ants.image_read(fixed_file)
    moving = ants.image_read(moving_file)
    li2mni = ants.apply_transforms(
        fixed=fixed, moving=moving, interpolator="bSpline",
        transformlist=transformlist)
    li2mni.to_filename(filename)


def apply_translation(image_file, translation, filename):
    """ Apply a translation to an image.

    Parameters
    ----------
    image_file: str
        input image.
    translation: 3-uplet
        the translation in mm.
    filename: str
        the name of the transformed image.
    """
    im = nibabel.load(image_file)
    affine = im.affine
    affine[:3, 3] += translation
    im = nibabel.Nifti1Image(im.get_fdata(), affine)
    nibabel.save(im, filename)



# -*- coding: utf-8 -*-
##########################################################################
# NSAp - Copyright (C) CEA, 2022
# Distributed under the terms of the CeCILL-B license, as published by
# the CEA-CNRS-INRIA. Refer to the LICENSE file or to
# http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
# for details.
##########################################################################

"""
Normalization tools.
"""

# Imports
import os
import subprocess
import numpy as np
import nibabel
from .regtools import flirt2aff


def gzfile(input_image, output_image):
    """ Gzip a file if necessary.

    Parameters
    ----------
    input_image: str
        the image to reorient.
    output_image: str
        the gzip image.

    Returns
    -------
    gzip_image: str
        the gzip file.
    """
    im = nibabel.load(input_image)
    nibabel.save(im, output_image)
    return output_image


def fslreorient2std(input_image, output_image, save_trf=True):
    """ Reorient an image to match the approximate orientation of the standard
    template image (MNI152).

    Parameters
    ----------
    input_image: str
        the image to reorient.
    output_image: str
        the reoriented image.
    save_trf: bool, default True
        opttionally save the reorientation matrix.
    """
    cmd1 = ["fslreorient2std", input_image, output_image]
    cmd2 = ["fslreorient2std", input_image]
    subprocess.check_call(cmd1)
    if save_trf:
        stdout = subprocess.check_output(cmd2)
        fsl_trf_file = output_image.split(".")[0] + ".fsl.trf"
        with open(fsl_trf_file, "wt") as open_file:
            open_file.write(stdout.decode("utf8"))
        trf_file = output_image.split(".")[0] + ".trf"
        np.savetxt(trf_file, flirt2aff(fsl_trf_file, output_image,
                                       input_image))
    return output_image


def fast(input_file, out_fileroot, klass=3, im_type=1, segments=False,
         bias_field=True, bias_corrected_im=True, probabilities=False):
    """ FAST (FMRIB's Automated Segmentation Tool) segments a 3D image of
    the brain into different tissue types (Grey Matter, White Matter, CSF,
    etc.), whilst also correcting for spatial intensity variations (also
    known as bias field or RF inhomogeneities).

    Parameters
    ----------
    input_file: str
        the image to be segmented.
    out_fileroot: str
        output basename.
    klass: int, default 3
        number of tissue-type classes.
    im_type: int, default 1
        type of image 1=T1, 2=T2, 3=PD.
    segments: bool, default False
        outputs a separate binary image for each tissue type.
    bias_field, default True
        output estimated bias field.
    bias_corrected_im: bool, default True
        output bias-corrected image.
    probabilities: bool, default False
        outputs individual probability maps.

    Returns
    -------
    biascorrected_file: str
        the bias corrected input image.
    """
    bool_params = {
        "-g": segments,
        "-b": bias_field,
        "-B": bias_corrected_im,
        "-p": probabilities
    }
    cmd = ["fast", "-o", out_fileroot, "-n", str(klass), "-t", str(im_type)]
    for name, value in bool_params.items():
        if value:
            cmd.append(name)
    cmd.append(input_file)
    subprocess.check_call(cmd)
    image_ext = ".nii.gz"
    biascorrected_file = out_fileroot + "_restore" + image_ext
    if not os.path.isfile(biascorrected_file):
        biascorrected_file = None
    return biascorrected_file



# -*- coding: utf-8 -*-
##########################################################################
# NSAp - Copyright (C) CEA, 2019
# Distributed under the terms of the CeCILL-B license, as published by
# the CEA-CNRS-INRIA. Refer to the LICENSE file or to
# http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
# for details.
##########################################################################

"""
A module with common functions.
"""

# System import
import os
import gzip
import re
import subprocess
from .info import __version__, LICENSE, AUTHOR, DESCRIPTION


def logo():
    """ http://patorjk.com/software/taag/#p=display&f=Big&t=Limri

    Returns
    -------
    logo: str
        the logo.
    """
    logo = r"""
  _      _                _
 | |    (_)              (_)
 | |     _ _ __ ___  _ __ _
 | |    | | '_ ` _ \| '__| |
 | |____| | | | | | | |  | |
 |______|_|_| |_| |_|_|  |_|
                            """
    return logo


def info():
    """ Dispaly some usefull information about the package.

    Returns
    -------
    info: str
        package information.
    """
    rchar = "\n"
    version = f"Package version: {__version__.strip(rchar)}\n"
    license = f"License: {LICENSE.strip(rchar)}\n"
    authors = f"Authors: {AUTHOR.strip(rchar)}\n"
    desc = f"Description: {DESCRIPTION.strip(rchar)}\n"
    return logo() + "\n" + desc + version + license + authors


def ungzip_file(zfile, prefix="u", outdir=None):
    """ Copy and ungzip the input file.

    Parameters
    ----------
    zfile: str
        input file to ungzip.
    prefix: str, default 'u'
        the prefix of the result file.
    outdir: str, default None)
        the output directory where ungzip file is saved. If not set use the
        input image directory.

    Returns
    -------
    unzfile: str
        the ungzip file.
    """
    # Checks
    if not os.path.isfile(zfile):
        raise ValueError("'{0}' is not a valid filename.".format(zfile))
    if outdir is not None:
        if not os.path.isdir(outdir):
            raise ValueError("'{0}' is not a valid directory.".format(outdir))
    else:
        outdir = os.path.dirname(zfile)

    # Get the file descriptors
    base, extension = os.path.splitext(zfile)
    basename = os.path.basename(base)

    # Ungzip only known extension
    if extension in [".gz"]:
        basename = prefix + basename
        unzfile = os.path.join(outdir, basename)
        with gzip.open(zfile, "rb") as gzfobj:
            data = gzfobj.read()
        with open(unzfile, "wb") as openfile:
            openfile.write(data)

    # Default, unknown compression extension: the input file is returned
    else:
        unzfile = zfile

    return unzfile


def create_bids_filetree(filepath, dest_path):
    # write the results in bids format
    path_tmp = filepath.split(os.sep)
    filename = os.path.basename(filepath)
    if not re.search("ses-", filename):
        raise ValueError("session key is needed")
    ses = path_tmp[-3]
    sub = path_tmp[-4]
    sub_dest = os.path.join(dest_path, sub)
    ses_dest = os.path.join(sub_dest, ses)
    anatdest = os.path.join(ses_dest, "anat")
    # create filetree
    subprocess.check_call(['mkdir', '-p', anatdest])
    return 0


def create_symbolic_link(filepath, dest_path):
    newpath = os.path.dirname(filepath)
    newpath = newpath.split(os.sep)[-3:]
    newpath = os.sep.join(dest_path, newpath)
    cmd = ["ln", "-s", filepath, newpath]
    subprocess.check_call(cmd)
    return 0



# -*- coding: utf-8 -*-
##########################################################################
# NSAp - Copyright (C) CEA, 2023
# Distributed under the terms of the CeCILL-B license, as published by
# the CEA-CNRS-INRIA. Refer to the LICENSE file or to
# http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
# for details.
##########################################################################

"""
Workflows definition.
"""

# Imports
import os
import glob
import limri
from limri.normtools import fslreorient2std, fast, gzfile
from limri.regtools import antsregister, apply_transforms, apply_translation
from limri.color_utils import print_title, print_result, print_warning


def li2mni(li_file, lianat_file, hanat_file, outdir, li2lianat=None):
    """ Transform the Lithium (Li) data to the MNI space by using intermediate
    Hydrogene (H) data.

    Parameters
    ----------
    li_file: str
        path to the Li image.
    lianat_file: str
        path to the anat image acquired with the Li coil.
    hanat_file: str
        path of the anat image acquired with the H coil.
    outdir: str
        path to the destination folder.
    li2lianat: 3-uplet, default None
        the translation applied on the Li image to compensate for different
        field of view between the Li and Li anat images (in mm).
    """
    print_title("Reorient images...")
    lianat_reo_file = os.path.join(outdir, "lianat.nii.gz")
    if not os.path.isfile(lianat_reo_file):
        gzfile(lianat_file, lianat_reo_file)
        fslreorient2std(lianat_reo_file, lianat_reo_file, save_trf=True)
    else:
        print_warning("lianat already reoriented")
    print_result(lianat_reo_file)
    hanat_reo_file = os.path.join(outdir, "hanat.nii.gz")
    if not os.path.isfile(hanat_reo_file):
        gzfile(hanat_file, hanat_reo_file)
        fslreorient2std(hanat_reo_file, hanat_reo_file, save_trf=True)
    else:
        print_warning("hanat already reoriented")
    print_result(hanat_reo_file)

    print_title("Bias field correction...")
    lianat_bcorr_file = os.path.join(outdir, "lianat_restore.nii.gz")
    if not os.path.isfile(lianat_bcorr_file):
        lianat_bcorr_file = fast(
            lianat_reo_file, lianat_reo_file.replace(".nii.gz", ""))
    else:
        print_warning("lianat already bias corrected")
    print_result(lianat_bcorr_file)
    hanat_bcorr_file = os.path.join(outdir, "hanat_restore.nii.gz")
    if not os.path.isfile(hanat_bcorr_file):
        hanat_bcorr_file = fast(
            hanat_reo_file, hanat_reo_file.replace(".nii.gz", ""))
    else:
        print_warning("hanat already bias corrected")
    for key1 in ("lianat", "hanat"):
        for key2 in ("pve", "mixeltype", "seg"):
            regex = os.path.join(outdir, f"{key1}_{key2}*.nii.gz")
            for path in glob.glob(regex):
                os.remove(path)
    print_result(hanat_bcorr_file)

    print_title("Coregistration & normalization...")
    rigid_transforms = [os.path.join(outdir, "li2h0GenericAffine.mat")]
    deform_transforms = [
        os.path.join(outdir, "h2mni1Warp.nii.gz"),
        os.path.join(outdir, "h2mni0GenericAffine.mat")]
    is_generated = True
    for path in rigid_transforms + deform_transforms:
        if not os.path.isfile(path):
            is_generated = False
            break
    ref_file = os.path.join(os.path.dirname(limri.__file__), "resources",
                            "MNI152_T1_2mm.nii.gz")
    if not is_generated:
        antsregister(
            template_file=ref_file, lianat_file=lianat_bcorr_file,
            hanat_file=hanat_bcorr_file, outdir=outdir)
    else:
        print_warning("li2mni transformation already computed")
    print_result(deform_transforms + rigid_transforms)

    print_title("Li image to MNI space...")
    li2mni_file = os.path.join(outdir, "li2mni.nii.gz")
    if not os.path.isfile(li2mni_file):
        li2lianat = li2lianat or (0, 0, 0)
        apply_translation(image_file=li_file, translation=li2lianat,
                          filename=li2mni_file)
        apply_transforms(
            fixed_file=ref_file, moving_file=li2mni_file,
            transformlist=deform_transforms + rigid_transforms,
            filename=li2mni_file)
    else:
        print_warning("li2mni transformation already applied")
    print_result(li2mni_file)



# -*- coding: utf-8 -*-
##########################################################################
# NSAp - Copyright (C) CEA, 2021
# Distributed under the terms of the CeCILL-B license, as published by
# the CEA-CNRS-INRIA. Refer to the LICENSE file or to
# http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
# for details.
##########################################################################

# Module current version
version_major = 0
version_minor = 0
version_micro = 0

# Expected by setup.py: string of form "X.Y.Z"
__version__ = "{0}.{1}.{2}".format(version_major, version_minor, version_micro)

# Expected by setup.py: the status of the project
CLASSIFIERS = ["Development Status :: 5 - Production/Stable",
               "Environment :: Console",
               "Environment :: X11 Applications :: Qt",
               "Operating System :: OS Independent",
               "Programming Language :: Python",
               "Topic :: Scientific/Engineering",
               "Topic :: Utilities"]

# Project descriptions
description = """
Package that provides tools for brain Lithium MRI pre-processing.
"""
SUMMARY = """
.. container:: summary-carousel

    `Limri` is a toolbox that provides common lithium brain
    MRI PreProcessing scripts:

    * li2mni
"""
long_description = (
    "Package that provides tools for brain Lithium MRI pre-processing.\n")

# Main setup parameters
NAME = "limri"
ORGANISATION = "CEA"
MAINTAINER = "Antoine Grigis"
MAINTAINER_EMAIL = "antoine.grigis@cea.fr"
DESCRIPTION = description
LONG_DESCRIPTION = long_description
EXTRANAME = "NeuroSpin webPage"
EXTRAURL = (
    "https://joliot.cea.fr/drf/joliot/Pages/Entites_de_recherche/"
    "NeuroSpin.aspx")
LINKS = {"scripts": "https://github.com/neurospin/scripts"}
URL = "https://github.com/rlink7/rlink_7limri"
DOWNLOAD_URL = "https://github.com/rlink7/rlink_7limri"
LICENSE = "CeCILL-B"
AUTHOR = """
Limri developers
"""
AUTHOR_EMAIL = "antoine.grigis@cea.fr"
PLATFORMS = "OS Independent"
ISRELEASE = True
VERSION = __version__
PROVIDES = ["limri"]
REQUIRES = [
    "numpy",
    "nibabel",
    "antspyx"
]
SCRIPTS = [
    "limri/scripts/limri"
]
